@@ -112,7 +112,7 @@ class DiscreteEnv(gym.Env):
     
     #depending on the value of self.state, apply a reward
     #done = np.any(Prob1 < 0.2)    
-    #reward = 0
+    reward = 0
     
     #if done:
       #reward = self.Ynew_cumul 
